@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2011-2016, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2011-2024, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -38,25 +38,82 @@ using std::accumulate;
 #include "MetaPopInfo.h"
 #include "Vcf.h"
 
+struct MethylData {
+    uint16_t tot_depth;
+    uint16_t col;
+    methylt  type;
+    MethylData() : tot_depth(0), col(0), type(methylt::irrelevant) {}
+    MethylData(uint16_t d, uint16_t c, methylt t) : tot_depth(d), col(c), type(t) {}
+};
+
+class MethylLoc {
+    vector<MethylData> _mdata;
+    uint16_t           _index;
+    uint16_t           _max_col;
+
+public:
+    MethylLoc() : _index(UINT16_MAX), _max_col(UINT16_MAX) {}
+    MethylLoc(uint16_t depth, uint16_t col, methylt type) {
+        _index   = UINT16_MAX;
+        _max_col = col;
+        _mdata.push_back(MethylData(depth, col, type));
+    }
+    void reset() {
+        _index = UINT16_MAX;
+    }
+    void add(uint16_t depth, uint16_t col, methylt type) {
+        if (type == methylt::irrelevant)
+            return;
+        
+        if (_max_col != UINT16_MAX) assert(col > _max_col);
+
+        _mdata.push_back(MethylData(depth, col, type));
+        _max_col = col;
+        return;
+    }
+    MethylData pos(uint16_t col) {
+        // Columns in _mdata are not contiguous, we only store sites with data.
+
+        // No sites for this locus.
+        if (_mdata.size() == 0 && _index == UINT16_MAX)
+            return MethylData(0, col, methylt::irrelevant);
+
+        if (_index == UINT16_MAX)
+            _index = 0;
+
+        if (col < _mdata[_index].col || col > _max_col)
+            return MethylData(0, col, methylt::irrelevant);
+
+        if (col == _mdata[_index].col) {
+            uint16_t ret_index = _index;
+            _index++;
+            return _mdata[ret_index];
+        }
+
+        return MethylData();
+    }
+};
+
 class Datum {
 public:
     struct SNPData {
-        size_t tot_depth;
+        size_t      tot_depth;
         Counts<Nt2> nt_depths;
-        uint8_t gq;
-        GtLiks gtliks;
+        uint8_t     gq;
+        GtLiks      gtliks;
         SNPData() : tot_depth(0), gq(UINT8_MAX) {}
     };
 
-    int             id;            // Stack ID
-    int             merge_partner; // Stack ID of merged datum, if this datum was merged/phased from two, overlapping datums.
-    int             len;           // Length of locus
-    char           *model;         // String representing SNP model output for each nucleotide at this locus.
-    char           *gtype;         // Mapping genotype
-    char           *cigar;         // CIGAR string describing how the datum aligns to the catalog locus.
-    vector<char *>  obshap;        // Observed Haplotypes
+    int   id;            // Stack ID
+    int   merge_partner; // Stack ID of merged datum, if this datum was merged/phased from two, overlapping datums.
+    int   len;           // Length of locus
+    char *model;         // String representing SNP model output for each nucleotide at this locus.
+    char *gtype;         // Mapping genotype
+    char *cigar;         // CIGAR string describing how the datum aligns to the catalog locus.
+    vector<char *>  obshap;  // Observed Haplotypes
     vector<SNPData> snpdata;
-
+    MethylLoc       methyldata;
+    
     Datum()  {
         this->id            = -1;
         this->gtype         = NULL;
@@ -77,7 +134,8 @@ public:
         if (g.length() == 0) return;
         if (this->gtype != NULL) delete [] this->gtype;
         this->gtype = new char [g.length() + 1];
-        strcpy(this->gtype, g.c_str());
+        strncpy(this->gtype, g.c_str(), g.length());
+	this->gtype[g.length()] = '\0';
     }
     string genotype() { return string(this->gtype); }
 };
@@ -258,10 +316,11 @@ void PopMap<LocusT>::populate_internal(
     size_t ad_index = SIZE_MAX;
     size_t gq_index = SIZE_MAX;
     size_t gl_index = SIZE_MAX;
+    size_t my_index = SIZE_MAX;
     for (auto& rec : vcf_records)
     { try {
-        size_t col = rec.pos();
-        bool snp_rec = !rec.is_monomorphic();
+        size_t col     = rec.pos();
+        bool   snp_rec = !rec.is_monomorphic();
         if (snp_rec) {
             if (!rec.is_snp()) {
                 cerr << "Error: Not a SNP.\n";
@@ -277,9 +336,18 @@ void PopMap<LocusT>::populate_internal(
             ad_index = rec.index_of_gt_subfield("AD");
             gq_index = rec.index_of_gt_subfield("GQ");
             gl_index = rec.index_of_gt_subfield("GL");
+	    if (vcf_header.methyl())
+		my_index = rec.index_of_gt_subfield("MY");
+
+        } else if (vcf_header.methyl()) {
+            assert(rec.count_formats() == 2 && strcmp(rec.format0(),"DP")==0);
+	    dp_index = rec.index_of_gt_subfield("DP");
+	    my_index = rec.index_of_gt_subfield("MY");
+
         } else {
-            assert(rec.count_formats() == 1 && strcmp(rec.format0(),"DP")==0);
-        }
+	    assert(rec.count_formats() == 1 && strcmp(rec.format0(),"DP")==0);
+	}
+
         VcfRecord::iterator gt_itr = rec.begin_samples();
         for (size_t sample_vcf_i = 0;
             sample_vcf_i < vcf_header.samples().size();
@@ -334,6 +402,16 @@ void PopMap<LocusT>::populate_internal(
                     strncpy(d->obshap[0], "consensus", 10);
                 }
             }
+	    
+	    //
+	    // Record methyltation status, if available.
+	    //
+	    if (vcf_header.methyl()) {
+                d->methyldata.add(VcfRecord::util::parse_gt_dp(gt_str, dp_index),
+                                  col,
+                                  VcfRecord::util::parse_gt_my(gt_str, my_index));
+	    }
+	    
             // Handle the non-SNP-record case.
             if (!snp_rec) {
                 d->model[col] = 'O';
