@@ -45,7 +45,7 @@ LocPopSum::~LocPopSum()
 }
 
 int
-LocPopSum::sum_pops(const CSLocus *cloc, Datum const*const* d, const MetaPopInfo &mpopi,
+LocPopSum::sum_pops(const CSLocus *cloc, Datum **d, const MetaPopInfo &mpopi,
                     bool verbose, ostream &log_fh)
 {
     uint len = strlen(cloc->con);
@@ -90,9 +90,17 @@ LocPopSum::sum_pops(const CSLocus *cloc, Datum const*const* d, const MetaPopInfo
             this->tally_fixed_pos(cloc, d, s, k, pop.first_sample, pop.last_sample);
         }
 
+	if (methyl_ann) {
+	    for (uint k = 0; k < len; k++)
+		this->tally_methyl_pos(cloc, d, s, k, pop.first_sample, pop.last_sample);
+            for (uint k = pop.first_sample; k <= pop.last_sample; k++)
+                d[k]->methyldata.reset();
+
+        }
+	
         snp_cols.clear();
     }
-
+    
     return 0;
 }
 
@@ -347,6 +355,92 @@ LocPopSum::tally_heterozygous_pos(const CSLocus *cloc, Datum const*const* d, Loc
     return 0;
 }
 
+int
+LocPopSum::tally_methyl_pos(const CSLocus *cloc, Datum **d, LocSum *s,
+			    int pos, uint start, uint end)
+{
+    s->nucs[pos].methyl_type(methylt::irrelevant);
+    s->nucs[pos].methyl_freq(0.0);
+
+    vector<size_t> methyl_calls (4, 0);
+    // methyl_calls[0] --> unmethyl_cpg
+    // methyl_calls[1] --> unmethyl_chg
+    // methyl_calls[2] --> unmethyl_chh
+    // methyl_calls[3] --> unmethyl_unk
+
+    // if (cloc->id == 13552) {
+    //     cerr << "HERE\n";
+    // }
+    
+    uint16_t num_indv = 0;
+    for (uint i = start; i <= end; i++) {
+        if (d[i] == NULL || pos >= d[i]->len)
+            continue;
+
+	//
+        // Pull any unmethylated marking from this position in this individual.
+        //
+        MethylData md = d[i]->methyldata.pos(pos);
+	switch(md.type) {
+	case methylt::unmethyl_cpg:
+	    methyl_calls[0]++;
+	    num_indv++;
+	    break;
+	case methylt::unmethyl_chg:
+	    methyl_calls[1]++;
+	    num_indv++;
+	    break;
+	case methylt::unmethyl_chh:
+	    methyl_calls[2]++;
+	    num_indv++;
+	    break;
+	case methylt::unmethyl_unk:
+	    methyl_calls[3]++;
+	    num_indv++;
+	    break;
+	default:
+	    break;
+        }
+    }
+
+    //
+    // Determine how many alleles are present at this position in this population.
+    // We cannot deal with more than two alternative alleles, if there are more than two
+    // in a single population, print a warning and exclude this nucleotide position.
+    //
+    int methyl_cnt = 0;
+    for (size_t i = 0; i < 4; i++)
+        if (methyl_calls[i] > 0) methyl_cnt++;
+
+    methylt methyl_type = methylt::irrelevant;
+
+    switch (methyl_cnt) {
+    case 0:
+	return 0;
+    case 1:
+	if (methyl_calls[0] > 0)
+	    methyl_type = methylt::unmethyl_cpg;
+	else if (methyl_calls[1] > 0)
+	    methyl_type = methylt::unmethyl_chg;
+	else if (methyl_calls[2] > 0)
+	    methyl_type = methylt::unmethyl_chh;
+	else
+	    methyl_type = methylt::unmethyl_unk;
+	break;
+    default:
+        methyl_type = methylt::confounded;
+	break;
+    }
+
+    //
+    // Record the results in the PopSum object.
+    //
+    s->nucs[pos].methyl_type(methyl_type);
+    s->nucs[pos].methyl_freq((float) num_indv / (float) (end - start + 1));
+
+    return 0;
+}
+
 double
 LocPopSum::pi(double tot_alleles, double p, double q)
 {
