@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2011-2023, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2011-2024, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -37,6 +37,7 @@
 #include "MetaPopInfo.h"
 #include "Hwp.h"
 
+extern bool      methyl_ann;
 extern bool      calc_hwp;
 extern double    minor_allele_freq;
 extern corr_type fst_correction;
@@ -255,6 +256,8 @@ class SumStat: public PopStat {
     };
     bool     _filtered_site;
     uint16_t _num_indv;
+    methylt  _methyl_type;
+    float    _methyl_freq;
     char     _p_nuc;
     HetNuc  *_het_nuc;
 
@@ -264,6 +267,8 @@ public:
         _num_indv      = 0;
         _p_nuc         = 0;
         _filtered_site = false;
+	_methyl_type   = methylt::irrelevant;
+	_methyl_freq   = 0.0;
     }
     ~SumStat() {
         if (this->_het_nuc != NULL)
@@ -328,6 +333,10 @@ public:
     void     exp_het(float exp_het) { if (this->_het_nuc != NULL) this->_het_nuc->_exp_het = exp_het; }
     float    exp_hom()              { if (this->_het_nuc != NULL) return this->_het_nuc->_exp_hom; else return 1.0; }
     void     exp_hom(float exp_hom) { if (this->_het_nuc != NULL) this->_het_nuc->_exp_hom = exp_hom; }
+    methylt  methyl_type()          { return this->_methyl_type; }
+    void     methyl_type(methylt t) { this->_methyl_type = t; }
+    float    methyl_freq()          { return this->_methyl_freq; }
+    void     methyl_freq(float f)   { this->_methyl_freq = f; }
     bool     filtered_site()        { return this->_filtered_site; }
     void     filtered_site(bool v)  { this->_filtered_site = v; }
 
@@ -479,7 +488,7 @@ public:
     LocPopSum(size_t cloc_len, const MetaPopInfo& mpopi);
     ~LocPopSum();
 
-    int             sum_pops(const CSLocus *, Datum const*const*, const MetaPopInfo&, bool, ostream &);
+    int             sum_pops(const CSLocus *, Datum **, const MetaPopInfo&, bool, ostream &);
     int             tally_metapop(const CSLocus *);
     int             calc_hapstats(const CSLocus *, const Datum **, const MetaPopInfo&);
     const LocSum  **all_pops()                         { return (const LocSum **) this->_per_pop; }
@@ -494,6 +503,7 @@ public:
 private:
     int      tally_heterozygous_pos(const CSLocus *, Datum const*const*, LocSum *, int, int, uint, uint);
     int      tally_fixed_pos(const CSLocus *, Datum const*const*, LocSum *, int, uint, uint);
+    int      tally_methyl_pos(const CSLocus *, Datum **, LocSum *, int, uint, uint);
     int      tally_ref_alleles(int, uint16_t &, char &, char &, uint16_t &, uint16_t &);
     int      tally_observed_haplotypes(const vector<char *> &, int);
     LocStat *haplotype_diversity(int, int, Datum const*const*);
