@@ -53,6 +53,29 @@ void VcfHeader::add_std_meta(const string& version) {
 
     add_meta(VcfMeta("source", string("\"Stacks v") + VERSION + "\""));
 
+    add_meta(VcfMeta::predefs::info_AD);
+    add_meta(VcfMeta::predefs::info_AF);
+    add_meta(VcfMeta::predefs::info_DP);
+    add_meta(VcfMeta::predefs::info_NS);
+    add_meta(VcfMeta::predefs::format_AD);
+    add_meta(VcfMeta::predefs::format_DP);
+    add_meta(VcfMeta::predefs::format_HQ);
+    add_meta(VcfMeta::predefs::format_GL);
+    add_meta(VcfMeta::predefs::format_GQ);
+    add_meta(VcfMeta::predefs::format_GT);
+}
+
+void VcfHeader::add_methyl_meta(const string& version) {
+    add_meta(VcfMeta("fileformat", version));
+
+    time_t t;
+    time(&t);
+    char date[9];
+    strftime(date, 9, "%Y%m%d", localtime(&t));
+    add_meta(VcfMeta("fileDate", date));
+
+    add_meta(VcfMeta("source", string("\"Stacks v") + VERSION + "\""));
+
     add_meta(VcfMeta::predefs::info_AD);
     add_meta(VcfMeta::predefs::info_AF);
     add_meta(VcfMeta::predefs::info_DP);
@@ -90,8 +113,33 @@ void VcfHeader::add_std_meta_with_contigs(const vector<Contig> &contigs, const s
     add_meta(VcfMeta::predefs::format_GL);
     add_meta(VcfMeta::predefs::format_GQ);
     add_meta(VcfMeta::predefs::format_GT);
-    add_meta(VcfMeta::predefs::format_MY);
+}
 
+void VcfHeader::add_methyl_meta_with_contigs(const vector<Contig> &contigs, const string& version) {
+    add_meta(VcfMeta("fileformat", version));
+
+    time_t t;
+    time(&t);
+    char date[9];
+    strftime(date, 9, "%Y%m%d", localtime(&t));
+    add_meta(VcfMeta("fileDate", date));
+
+    add_meta(VcfMeta("source", string("\"Stacks v") + VERSION + "\""));
+
+    for (auto &ctg: contigs)
+	add_meta(VcfMeta("contig", "<ID=" + ctg.name + ",length=" + ctg.length + ">"));
+    
+    add_meta(VcfMeta::predefs::info_AD);
+    add_meta(VcfMeta::predefs::info_AF);
+    add_meta(VcfMeta::predefs::info_DP);
+    add_meta(VcfMeta::predefs::info_NS);
+    add_meta(VcfMeta::predefs::format_AD);
+    add_meta(VcfMeta::predefs::format_DP);
+    add_meta(VcfMeta::predefs::format_HQ);
+    add_meta(VcfMeta::predefs::format_GL);
+    add_meta(VcfMeta::predefs::format_GQ);
+    add_meta(VcfMeta::predefs::format_GT);
+    add_meta(VcfMeta::predefs::format_MY);
 }
 
 void VcfRecord::assign(const char* rec, size_t len, const VcfHeader& header) {
@@ -228,6 +276,40 @@ size_t VcfRecord::util::parse_gt_dp(
     return dp;
 }
 
+methylt VcfRecord::util::parse_gt_my(
+    const char* gt_str,
+    size_t my_index
+) {
+    const char* p = VcfRecord::util::find_gt_subfield(gt_str, my_index);
+    if (p == NULL) {
+        cerr << "Error: MY field is missing.\n";
+        throw exception();
+    }
+    methylt my;
+    
+    switch(*p) {
+    case '.':
+	my = methylt::irrelevant;
+	break;
+    case 'z':
+	my = methylt::unmethyl_cpg;
+	break;
+    case 'x':
+	my = methylt::unmethyl_chg;
+	break;
+    case 'h':
+	my = methylt::unmethyl_chh;
+	break;
+    case 'u':
+	my = methylt::unmethyl_unk;
+	break;
+    default:
+        cerr << "Error: Bad MY field.\n";
+        throw exception();
+    }
+    return my;
+}
+
 Counts<Nt2>
 VcfRecord::util::parse_gt_ad(
     const char* gt_str,
@@ -409,4 +491,12 @@ VcfParser::read_header()
             p = next;
         } while (p != end);
     }
+
+    //
+    // Check if the VCF header contained a definition of methylated data, e.g.
+    // ##FORMAT=<ID=MY,Number=1,Type=String,Description="Methylation Annotation">
+    //
+    for (auto m: header_.meta())
+	if (m.key() == "FORMAT" && m.value().substr(4,2) == "MY")
+	    header_.methyl(true);
 }
