@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2010-2023, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2010-2024, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -21,6 +21,7 @@
 #ifndef __VCF_H__
 #define __VCF_H__
 
+#include "stacks.h"
 #include "constants.h"
 #include "nucleotides.h"
 #include "utils.h"
@@ -67,14 +68,15 @@ public:
  * Stores the contents of a VCF header.
  */
 class VcfHeader {
-    vector<string> samples_;
-    vector<VcfMeta> meta_;
+    vector<string>      samples_;
+    vector<VcfMeta>     meta_;
     map<string, size_t> sample_indexes_;
-
+    bool                contains_methylation_;
+    
     template<typename OStream> void print(OStream& os) const; // Template because VersatileWriter isn't a proper std::ostream.
 
 public:
-    VcfHeader() : samples_(), meta_(), sample_indexes_() {}
+    VcfHeader() : samples_(), meta_(), sample_indexes_(), contains_methylation_(false) {}
 
     const vector<VcfMeta>& meta() const {return meta_;}
     const vector<string>& samples() const {return samples_;}
@@ -83,11 +85,18 @@ public:
     void add_meta(const VcfMeta& m) {meta_.push_back(m);}
     void add_sample(const string& s) {samples_.push_back(s); sample_indexes_.insert({s, samples_.size()-1});}
 
+    const bool methyl() const { return this->contains_methylation_; }
+    void methyl(const bool methyl) { this->contains_methylation_ = methyl; }
+    
     // Creates a standard header.
     void add_std_meta(const string& version = "VCFv4.2");
+    // Creates a standard header with methylation.
+    void add_methyl_meta(const string& version = "VCFv4.2");
 
     // Creates a standard header with contigs defined.
     void add_std_meta_with_contigs(const vector<Contig> &, const string& version = "VCFv4.2");
+    // Creates a standard header with methylation and contigs defined.
+    void add_methyl_meta_with_contigs(const vector<Contig> &, const string& version = "VCFv4.2");
 
     static const string std_fields;
 
@@ -190,7 +199,7 @@ public:
 
     static const char allele_sep = ',';
     static const char filter_sep = ';';
-    static const char info_sep = ';';
+    static const char info_sep   = ';';
     static const char format_sep = ':';
     static const char sample_sep = ':';
 
@@ -203,6 +212,7 @@ public:
         static Counts<Nt2> parse_gt_ad(const char* gt_str, size_t ad_index, const vector<Nt2>& alleles);
         static uint8_t parse_gt_gq(const char* gt_str, size_t gq_index);
         static GtLiks parse_gt_gl(const char* gt_str, size_t gl_index, const vector<Nt2>& alleles);
+	static methylt parse_gt_my(const char* gt_str, size_t my_index);
 
         static const char* find_gt_subfield(const char* sample, size_t n);
         static void skip_gt_subfields(const char** start, size_t n);
