@@ -697,13 +697,20 @@ correct_barcode(set<string> &bcs, RawRead *href, seqt type, int num_errs)
 // Functions for filtering adapter sequence
 //
 int
-init_adapter_seq(int kmer_size, char *adapter, int &adp_len, AdapterHash &kmers)
+init_adapter_seq(int &kmer_size, char *adapter, int &adp_len, int adp_mm_dist, AdapterHash &kmers)
 {
+    //
+    // Determine k-mer size, maxing out at k = 11 if the adapter is long enough.
+    //
+    adp_len   = strlen(adapter);
+    kmer_size = determine_kmer_length(adp_len, adp_mm_dist);
+
+    if (kmer_size > 9) kmer_size = 9;
+    
     string kmer;
-    adp_len = strlen(adapter);
+    int    num_kmers = adp_len - kmer_size + 1;
+    char  *p         = adapter;
 
-    int   num_kmers = adp_len - kmer_size + 1;
-    char *p = adapter;
     for (int i = 0; i < num_kmers; i++) {
         kmer.assign(p, kmer_size);
         kmers[kmer].push_back(i);
@@ -715,14 +722,14 @@ init_adapter_seq(int kmer_size, char *adapter, int &adp_len, AdapterHash &kmers)
 
 int
 filter_adapter_seq(RawRead *href, char *adapter, int adp_len, AdapterHash &adp_kmers,
-                   int kmer_size, int distance, int len_limit)
+                   int kmer_size, int adp_mm_dist, int len_limit)
 {
     vector<pair<int, int> > hits;
     int  query_stop = href->inline_bc_len;
     int   num_kmers = href->len - query_stop - kmer_size + 1;
     const char *p   = href->seq + query_stop;
     string kmer;
-
+    
     //
     // Identify matching kmers and their locations of occurance.
     //
@@ -732,7 +739,7 @@ filter_adapter_seq(RawRead *href, char *adapter, int adp_len, AdapterHash &adp_k
         if (adp_kmers.count(kmer) > 0) {
             for (uint j = 0; j < adp_kmers[kmer].size(); j++) {
                 // cerr << "Kmer hit " << kmer << " at query position " << i << " at hit position " << adp_kmers[kmer][j] << "\n";
-                hits.push_back(make_pair(i, adp_kmers[kmer][j]));
+                hits.push_back(make_pair( (p - href->seq), adp_kmers[kmer][j]));
             }
         }
         p++;
@@ -762,14 +769,14 @@ filter_adapter_seq(RawRead *href, char *adapter, int adp_len, AdapterHash &adp_k
             j--;
         }
         
-        if (mismatches > distance)
+        if (mismatches > adp_mm_dist)
             continue;
 
         start_pos = i + 1;
         i = hits[k].first;
         j = hits[k].second;
 
-        while (i < (int) href->len && j < adp_len && mismatches <= distance) {
+        while (i < (int) href->len && j < adp_len && mismatches <= adp_mm_dist) {
             if (href->seq[i] != adapter[j])
                 mismatches++;
             i++;
@@ -779,7 +786,7 @@ filter_adapter_seq(RawRead *href, char *adapter, int adp_len, AdapterHash &adp_k
         // cerr << "Starting position: " << start_pos << "; Query end (i): " << i << "; adapter end (j): " << j
         //      << "; number of mismatches: " << mismatches << "; Seq Len: " << href->len << "; SeqSeq Len: " << strlen(href->seq) << "\n";
 
-        if (mismatches <= distance && (i == (int) href->len || j == adp_len)) {
+        if (mismatches <= adp_mm_dist && (i == (int) href->len || j == adp_len)) {
             // cerr << "  Trimming or dropping.\n";
             if (start_pos < len_limit) {
                 return 0;
