@@ -403,7 +403,7 @@ int  reverse_qual(char *, int, bool);
 bool correct_barcode(set<string> &, RawRead *, seqt, int);
 
 int  filter_adapter_seq(RawRead *, char *, int, AdapterHash &, int, int, int);
-int  init_adapter_seq(int, char *, int &, AdapterHash &);
+int  init_adapter_seq(int &, char *, int &, int, AdapterHash &);
 
 int  check_quality_scores(RawRead *, int, int, int, int);
 int  check_poly_g_run(RawRead *, int, int);
