@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2010-2023, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2010-2024, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -1869,24 +1869,24 @@ int parse_command_line(int argc, char* argv[]) {
         static struct option long_options[] = {
             {"help",            no_argument, NULL, 'h'},
             {"version",         no_argument, NULL, 1000},
-            {"uniq-haplotypes", no_argument, NULL, 'u'}, {"uniq_haplotypes", no_argument, NULL, 'u'},
-            {"report-mmatches", no_argument, NULL, 'R'}, {"report_mmatches", no_argument, NULL, 'R'},
-            {"disable-gapped",  no_argument, NULL, 'G'}, {"disable_gapped",  no_argument, NULL, 'G'},
-            {"max-gaps",        required_argument, NULL, 'X'}, {"max_gaps",        required_argument, NULL, 'X'},
-            {"min-aln-len",     required_argument, NULL, 'x'}, {"min_aln_len",     required_argument, NULL, 'x'},
-            {"ctag-dist",       required_argument, NULL, 'n'}, {"ctag_dist",       required_argument, NULL, 'n'},
-            {"k-len",           required_argument, NULL, 'k'}, {"k_len",           required_argument, NULL, 'k'},
-            {"in-path",         required_argument, NULL, 'P'}, {"in_path",         required_argument, NULL, 'P'},
+            {"uniq-haplotypes", no_argument, NULL, 'u'},
+            {"report-mmatches", no_argument, NULL, 'R'},
+            {"disable-gapped",  no_argument, NULL, 'G'},
+            {"max-gaps",        required_argument, NULL, 'X'},
+            {"min-aln-len",     required_argument, NULL, 'x'}, 
+            {"ctag-dist",       required_argument, NULL, 'n'}, 
+            {"k-len",           required_argument, NULL, 'k'}, 
+            {"in-path",         required_argument, NULL, 'P'}, 
             {"popmap",          required_argument, NULL, 'M'},
             {"catalog",         required_argument, NULL, 'c'},
             {"sample",          required_argument, NULL, 's'},
-            {"out-path",        required_argument, NULL, 'o'}, {"out_path",        required_argument, NULL, 'o'},
-            {"threads",         required_argument, NULL, 'p'},
+            {"out-path",        required_argument, NULL, 'o'}, 
+            {"threads",         required_argument, NULL, 't'}, 
             {0, 0, 0, 0}
         };
 
         int option_index = 0;
-        int c = getopt_long(argc, argv, "hvuRGX:x:o:s:c:p:n:k:P:M:", long_options, &option_index);
+        int c = getopt_long(argc, argv, "hvuRGX:x:o:s:c:p:t:n:k:P:M:", long_options, &option_index);
 
         // Detect the end of the options.
         if (c == -1)
@@ -1931,6 +1931,7 @@ int parse_command_line(int argc, char* argv[]) {
             version();
             break;
         case 'p':
+        case 't':
             num_threads = is_integer(optarg);
             break;
         case 'P':
@@ -2005,13 +2006,13 @@ void version() {
 
 void help() {
     cerr << "cstacks " << VERSION << "\n"
-              << "cstacks -P in_dir -M popmap [-n num_mismatches] [-p num_threads]" << "\n"
-              << "cstacks -s sample1_path [-s sample2_path ...] -o path [-n num_mismatches] [-p num_threads]" << "\n"
+              << "cstacks -P in_dir -M popmap [-n num_mismatches] [-t num_threads]" << "\n"
+              << "cstacks -s sample1_path [-s sample2_path ...] -o path [-n num_mismatches] [-t num_threads]" << "\n"
               << "\n"
               << "  -P,--in-path: path to the directory containing Stacks files.\n"
               << "  -M,--popmap: path to a population map file.\n"
               << "  -n: number of mismatches allowed between sample loci when build the catalog (default 1; suggested: set to ustacks -M)." << "\n"
-              << "  -p,--threads: enable parallel execution with num_threads threads.\n"
+              << "  -t,--threads: enable parallel execution with num_threads threads.\n"
               << "  -s: sample prefix from which to load loci into the catalog." << "\n"
               << "  -o,--outpath: output path to write results." << "\n"
               << "  -c,--catalog <path>: add to an existing catalog.\n"
