@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2012-2022, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2012-2024, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -167,6 +167,22 @@ class HapstatsExport: public Export {
     int  write_batch(const vector<LocBin *> &);
 };
 
+class MethylSitesExport: public Export {
+    //
+    // Output the locus-level methylation statistics.
+    //
+    const MetaPopInfo *_mpopi;
+    uint  _pop_cnt;
+    static const std::string typestrs[];
+
+ public:
+    MethylSitesExport() : _mpopi(NULL), _pop_cnt(UINT_MAX) {}
+    ~MethylSitesExport() {}
+    int  open(const MetaPopInfo *mpopi);
+    int  write_header();
+    int  write_batch(const vector<LocBin *> &);
+};
+
 class SnpDivergenceExport: public Export {
     //
     // Output the SNP-level divergence statistics.
