@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2012-2021, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2012-2024, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -21,10 +21,6 @@
 //
 // file_io.cc -- common routines for opening groups of files and processing barcode lists.
 //
-// Julian Catchen
-// jcatchen@uoregon.edu
-// University of Oregon
-//
 
 #include "file_io.h"
 
@@ -56,8 +52,10 @@ open_files(vector<pair<string, string> > &files,
     BarcodePair bc;
     //
     // If the size of the barcodes vector is 0, then no barcodes
-    // were submitted. In this case, we want to open output files
-    // of the same name as input files, but in out_path.
+    // were submitted. In this case, we want to either:
+    //   1. open output files using out_basename, if supplied by the user, or
+    //   2. open output files of the same name as input files,
+    // in both cases opening the files in out_path.
     //
     if (barcodes.size() == 0 && merge == false) {
 
@@ -69,22 +67,26 @@ open_files(vector<pair<string, string> > &files,
             if (paired)
                 bc.pe = files[i].second;
 
-            path = out_path + files[i].first;
-
-            //
-            // Check that the file has a proper suffix for the output type.
-            //
-            pos  = path.find_last_of(".");
-            if (path.substr(pos) == ".bam") {
-                path = path.substr(0, pos) + suffix_1;
-            } else if (path.substr(pos) == ".gz") {
-                path = path.substr(0, pos);
-                pos  = path.find_last_of(".");
-                path = path.substr(0, pos) + suffix_1;
+            if (out_basename.length() > 0) {
+                path = out_path + out_basename + suffix_1;
+                
             } else {
-                path = path.substr(0, pos) + suffix_1;
+                path = out_path + files[i].first;
+                //
+                // Check that the file has a proper suffix for the output type.
+                //
+                pos  = path.find_last_of(".");
+                if (path.substr(pos) == ".bam") {
+                    path = path.substr(0, pos) + suffix_1;
+                } else if (path.substr(pos) == ".gz") {
+                    path = path.substr(0, pos);
+                    pos  = path.find_last_of(".");
+                    path = path.substr(0, pos) + suffix_1;
+                } else {
+                    path = path.substr(0, pos) + suffix_1;
+                }
             }
-
+            
             if (stat((in_path_1 + files[i].first).c_str(), &sb_1) == -1) {
                 cerr << "Unable to stat input file '" << in_path_1 + files[i].first << "'\n";
                 exit(1);
@@ -107,19 +109,25 @@ open_files(vector<pair<string, string> > &files,
 
             if (paired) {
                 file = interleaved ? files[i].first : files[i].second;
-                path = out_path + file;
 
-                pos = path.find_last_of(".");
-                if (path.substr(pos) == ".bam") {
-                    path = path.substr(0, pos) + suffix_2;
-                } else if (path.substr(pos) == ".gz") {
-                    path = path.substr(0, pos);
-                    pos  = path.find_last_of(".");
-                    path = path.substr(0, pos) + suffix_2;
+                if (out_basename.length() > 0) {
+                    path = out_path + out_basename + suffix_2;
+                    
                 } else {
-                    path = path.substr(0, pos) + suffix_2;
-                }
+                    path = out_path + file;
 
+                    pos = path.find_last_of(".");
+                    if (path.substr(pos) == ".bam") {
+                        path = path.substr(0, pos) + suffix_2;
+                    } else if (path.substr(pos) == ".gz") {
+                        path = path.substr(0, pos);
+                        pos  = path.find_last_of(".");
+                        path = path.substr(0, pos) + suffix_2;
+                    } else {
+                        path = path.substr(0, pos) + suffix_2;
+                    }
+                }
+                
                 if (stat((in_path_2 + file).c_str(), &sb_1) == -1) {
                     cerr << "Unable to stat input file '" << in_path_2 + file << "'\n";
                     exit(1);
@@ -140,17 +148,22 @@ open_files(vector<pair<string, string> > &files,
                     exit(1);
                 }
 
-                filepath = files[i].first;
-                pos      = filepath.find_last_of(".");
-                if (filepath.substr(pos) == ".gz") {
-                    filepath = filepath.substr(0, pos);
+                if (out_basename.length() > 0) {
+                    path = out_path + out_basename + ".rem" + suffix_1;
+                
+                } else {
+                    filepath = files[i].first;
                     pos      = filepath.find_last_of(".");
-                    filepath = filepath.substr(0, pos);
-                } else if (filepath.substr(pos) == ".bam") {
-                    filepath = filepath.substr(0, pos);
+                    if (filepath.substr(pos) == ".gz") {
+                        filepath = filepath.substr(0, pos);
+                        pos      = filepath.find_last_of(".");
+                        filepath = filepath.substr(0, pos);
+                    } else if (filepath.substr(pos) == ".bam") {
+                        filepath = filepath.substr(0, pos);
+                    }
+                    path = out_path + filepath + ".rem" + suffix_1;
                 }
-                path = out_path + filepath + ".rem" + suffix_1;
-
+                
                 fh = new ofstream(path.c_str(), ifstream::out);
                 rem_1_fhs[bc] = fh;
 
@@ -159,17 +172,22 @@ open_files(vector<pair<string, string> > &files,
                     exit(1);
                 }
 
-                filepath = file;
-                pos      = filepath.find_last_of(".");
-                if (filepath.substr(pos) == ".gz") {
-                    filepath = filepath.substr(0, pos);
+                if (out_basename.length() > 0) {
+                    path = out_path + out_basename + ".rem" + suffix_2;
+                
+                } else {
+                    filepath = file;
                     pos      = filepath.find_last_of(".");
-                    filepath = filepath.substr(0, pos);
-                } else if (filepath.substr(pos) == ".bam") {
-                    filepath = filepath.substr(0, pos);
+                    if (filepath.substr(pos) == ".gz") {
+                        filepath = filepath.substr(0, pos);
+                        pos      = filepath.find_last_of(".");
+                        filepath = filepath.substr(0, pos);
+                    } else if (filepath.substr(pos) == ".bam") {
+                        filepath = filepath.substr(0, pos);
+                    }
+                    path = out_path + filepath + ".rem" + suffix_2;
                 }
-                path = out_path + filepath + ".rem" + suffix_2;
-
+                
                 fh = new ofstream(path.c_str(), ifstream::out);
                 rem_2_fhs[bc] = fh;
 
@@ -184,7 +202,12 @@ open_files(vector<pair<string, string> > &files,
 
     } else if (barcodes.size() == 0 && merge == true) {
 
-        path = out_path + "sample_unbarcoded" + suffix_1;
+        if (out_basename.length() > 0) {
+            path = out_path + out_basename + suffix_1;
+                
+        } else {
+            path = out_path + "sample_unbarcoded" + suffix_1;
+        }
         fh   = new ofstream(path.c_str(), ifstream::out);
 
         if (fh->fail()) {
@@ -200,7 +223,12 @@ open_files(vector<pair<string, string> > &files,
         }
 
         if (paired) {
-            path = out_path + "sample_unbarcoded" + suffix_2;
+            if (out_basename.length() > 0) {
+                path = out_path + out_basename + suffix_2;
+                
+            } else {
+                path = out_path + "sample_unbarcoded" + suffix_2;
+            }
             fh   = new ofstream(path.c_str(), ifstream::out);
 
             if (fh->fail()) {
@@ -214,7 +242,12 @@ open_files(vector<pair<string, string> > &files,
                 pair_2_fhs[bc] = fh;
             }
 
-            path = out_path + "sample_unbarcoded.rem" + suffix_1;
+            if (out_basename.length() > 0) {
+                path = out_path + out_basename + ".rem" + suffix_1;
+                
+            } else {
+                path = out_path + "sample_unbarcoded.rem" + suffix_1;
+            }
             fh   = new ofstream(path.c_str(), ifstream::out);
 
             if (fh->fail()) {
@@ -228,7 +261,12 @@ open_files(vector<pair<string, string> > &files,
                 rem_1_fhs[bc] = fh;
             }
 
-            path = out_path + "sample_unbarcoded.rem" + suffix_2;
+            if (out_basename.length() > 0) {
+                path = out_path + out_basename + ".rem" + suffix_2;
+                
+            } else {
+                path = out_path + "sample_unbarcoded.rem" + suffix_2;
+            }
             fh   = new ofstream(path.c_str(), ifstream::out);
 
             if (fh->fail()) {
@@ -334,8 +372,10 @@ open_files(vector<pair<string, string> > &files,
     BarcodePair bc;
     //
     // If the size of the barcodes vector is 0, then no barcodes
-    // were submitted. In this case, we want to open output files
-    // of the same name as input files, but in out_path.
+    // were submitted. In this case, we want to either:
+    //   1. open output files using out_basename, if supplied by the user, or
+    //   2. open output files of the same name as input files,
+    // in both cases opening the files in out_path.
     //
     if (barcodes.size() == 0 && merge == false) {
 
@@ -347,20 +387,24 @@ open_files(vector<pair<string, string> > &files,
             if (paired)
                 bc.pe = files[i].second;
 
-            path = out_path + files[i].first;
-
-            //
-            // Check that the file has a proper suffix for the output type.
-            //
-            pos = path.find_last_of(".");
-            if (path.substr(pos) == ".bam") {
-                path = path.substr(0, pos) + suffix_1;
-            } else if (path.substr(pos) == ".gz") {
-                path = path.substr(0, pos);
-                pos  = path.find_last_of(".");
-                path = path.substr(0, pos) + suffix_1;
+            if (out_basename.length() > 0) {
+                path = out_path + out_basename + suffix_1;
+                
             } else {
-                path = path.substr(0, pos) + suffix_1;
+                path = out_path + files[i].first;
+                //
+                // Check that the file has a proper suffix for the output type.
+                //
+                pos = path.find_last_of(".");
+                if (path.substr(pos) == ".bam") {
+                    path = path.substr(0, pos) + suffix_1;
+                } else if (path.substr(pos) == ".gz") {
+                    path = path.substr(0, pos);
+                    pos  = path.find_last_of(".");
+                    path = path.substr(0, pos) + suffix_1;
+                } else {
+                    path = path.substr(0, pos) + suffix_1;
+                }
             }
 
             if (stat((in_path_1 + files[i].first).c_str(), &sb_1) == -1) {
@@ -385,18 +429,24 @@ open_files(vector<pair<string, string> > &files,
             }
 
             if (paired) {
-                file = interleaved ? files[i].first : files[i].second;
-                path = out_path + file;
 
-                pos = path.find_last_of(".");
-                if (path.substr(pos) == ".bam") {
-                    path.replace(pos, 4, suffix_2);
-                } else if (path.substr(pos) == ".gz") {
-                    path = path.substr(0, pos);
-                    pos  = path.find_last_of(".");
-                    path = path.substr(0, pos) + suffix_2;
+                if (out_basename.length() > 0) {
+                    path = out_path + out_basename + suffix_2;
+                    
                 } else {
-                    path = path.substr(0, pos) + suffix_2;
+                    file = interleaved ? files[i].first : files[i].second;
+                    path = out_path + file;
+
+                    pos = path.find_last_of(".");
+                    if (path.substr(pos) == ".bam") {
+                        path.replace(pos, 4, suffix_2);
+                    } else if (path.substr(pos) == ".gz") {
+                        path = path.substr(0, pos);
+                        pos  = path.find_last_of(".");
+                        path = path.substr(0, pos) + suffix_2;
+                    } else {
+                        path = path.substr(0, pos) + suffix_2;
+                    }
                 }
 
                 if (stat((in_path_2 + file).c_str(), &sb_1) == -1) {
@@ -420,17 +470,22 @@ open_files(vector<pair<string, string> > &files,
                     exit(1);
                 }
 
-                filepath = files[i].first;
-                pos      = filepath.find_last_of(".");
-                if (filepath.substr(pos) == ".gz") {
-                    filepath = filepath.substr(0, pos);
+                if (out_basename.length() > 0) {
+                    path = out_path + out_basename + ".rem" + suffix_1;
+                    
+                } else {
+                    filepath = files[i].first;
                     pos      = filepath.find_last_of(".");
-                    filepath = filepath.substr(0, pos);
-                } else if (filepath.substr(pos) == ".bam") {
-                    filepath = filepath.substr(0, pos);
+                    if (filepath.substr(pos) == ".gz") {
+                        filepath = filepath.substr(0, pos);
+                        pos      = filepath.find_last_of(".");
+                        filepath = filepath.substr(0, pos);
+                    } else if (filepath.substr(pos) == ".bam") {
+                        filepath = filepath.substr(0, pos);
+                    }
+                    path = out_path + filepath + ".rem" + suffix_1;
                 }
-                path = out_path + filepath + ".rem" + suffix_1;
-
+                
                 fh  = new gzFile;
                 *fh = gzopen(path.c_str(), "wb");
                 rem_1_fhs[bc] = fh;
@@ -440,17 +495,22 @@ open_files(vector<pair<string, string> > &files,
                     exit(1);
                 }
 
-                filepath = file;
-                pos      = filepath.find_last_of(".");
-                if (filepath.substr(pos) == ".gz") {
-                    filepath = filepath.substr(0, pos);
+                if (out_basename.length() > 0) {
+                    path = out_path + out_basename + ".rem" + suffix_2;
+                    
+                } else {
+                    filepath = file;
                     pos      = filepath.find_last_of(".");
-                    filepath = filepath.substr(0, pos);
-                } else if (filepath.substr(pos) == ".bam") {
-                    filepath = filepath.substr(0, pos);
+                    if (filepath.substr(pos) == ".gz") {
+                        filepath = filepath.substr(0, pos);
+                        pos      = filepath.find_last_of(".");
+                        filepath = filepath.substr(0, pos);
+                    } else if (filepath.substr(pos) == ".bam") {
+                        filepath = filepath.substr(0, pos);
+                    }
+                    path = out_path + filepath + ".rem" + suffix_2;
                 }
-                path = out_path + filepath + ".rem" + suffix_2;
-
+                
                 fh  = new gzFile;
                 *fh = gzopen(path.c_str(), "wb");
                 rem_2_fhs[bc] = fh;
@@ -463,9 +523,14 @@ open_files(vector<pair<string, string> > &files,
         }
 
         return 0;
+
     } else if (barcodes.size() == 0 && merge == true) {
 
-        path = out_path + "sample_unbarcoded" + suffix_1;
+        if (out_basename.length() > 0) {
+            path = out_path + out_basename + suffix_1;
+        } else {
+            path = out_path + "sample_unbarcoded" + suffix_1;
+        }
         fh   = new gzFile;
         *fh  = gzopen(path.c_str(), "wb");
 
@@ -482,7 +547,11 @@ open_files(vector<pair<string, string> > &files,
         }
 
         if (paired) {
-            path = out_path + "sample_unbarcoded" + suffix_2;
+            if (out_basename.length() > 0) {
+                path = out_path + out_basename + suffix_2;
+            } else {
+                path = out_path + "sample_unbarcoded" + suffix_2;
+            }
             fh   = new gzFile;
             *fh  = gzopen(path.c_str(), "wb");
 
@@ -497,7 +566,11 @@ open_files(vector<pair<string, string> > &files,
                 pair_2_fhs[bc] = fh;
             }
 
-            path = out_path + "sample_unbarcoded.rem" + suffix_1;
+            if (out_basename.length() > 0) {
+                path = out_path + out_basename + ".rem" + suffix_1;
+            } else {
+                path = out_path + "sample_unbarcoded.rem" + suffix_1;
+            }
             fh   = new gzFile;
             *fh  = gzopen(path.c_str(), "wb");
 
@@ -512,7 +585,11 @@ open_files(vector<pair<string, string> > &files,
                 rem_1_fhs[bc] = fh;
             }
 
-            path = out_path + "sample_unbarcoded.rem" + suffix_2;
+            if (out_basename.length() > 0) {
+                path = out_path + out_basename + ".rem" + suffix_2;
+            } else {
+                path = out_path + "sample_unbarcoded.rem" + suffix_2;
+            }
             fh   = new gzFile;
             *fh  = gzopen(path.c_str(), "wb");
 
@@ -909,10 +986,10 @@ load_barcodes(string barcode_file, vector<BarcodePair> &barcodes,
 int
 build_file_list(vector<pair<string, string> > &files)
 {
-    //
-    // Scan a directory for a list of files.
-    //
-    if (in_path_1.length() > 0) {
+    if (in_path_type == InputT::directory) {
+        //
+        // Scan a directory for a list of files.
+        //
         string file, paired_file;
         const char *p, *q, *end;
         struct dirent *direntry;
