@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2012, Julian Catchen <jcatchen@uoregon.edu>
+// Copyright 2012-2024, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -46,11 +46,13 @@
 //
 extern FileT     in_file_type;
 extern FileT     out_file_type;
+extern InputT    in_path_type;
 extern barcodet  barcode_type;
 extern bool      paired;
 extern bool      interleaved;
 extern bool      merge;
 extern string    out_path;
+extern string    out_basename;
 extern string    in_file;
 extern string    in_file_p1;
 extern string    in_file_p2;
