@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2013-2017, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2013-2021, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -31,28 +31,44 @@ void
 GzFasta::open(const char *path)
 {
     this->gz_fh = gzopen(path, "rb");
+
     if (!this->gz_fh) {
         cerr << "Failed to open gzipped file '" << path << "': " << strerror(errno) << ".\n";
         exit(EXIT_FAILURE);
     }
+
     #if ZLIB_VERNUM >= 0x1240
     gzbuffer(this->gz_fh, libz_buffer_size);
     #endif
-    int first = gzgetc(gz_fh);
-    if (first == -1) {
+
+    char *res = NULL;
+
+    // Skip blank lines and/or comments.
+    do {
+        res = gzgets(this->gz_fh, this->line, max_len);
+    } while (res != NULL && !gzeof(this->gz_fh) && (this->line[0] == '\n' || this->line[0] == '\r' || this->line[0] == '#'));
+
+    if (res == NULL && !gzeof(this->gz_fh)) {
         int errnum;
-        const char* errstr = gzerror(gz_fh, &errnum);
+        const char* errstr = gzerror(this->gz_fh, &errnum);
         cerr << "Error: Failed to read any content from '" << path
             << "' (gzerror: " << errstr << ").\n";
         exit(EXIT_FAILURE);
-    } else if (first != '>') {
+
+    } else if (this->line[0] != '>' && !gzeof(this->gz_fh)) {
         cerr << "Error: '" << path << "': not in fasta format (expected '>', got 0x"
-             << std::hex << first << " '" << flush << (char) first << "')."
+             << std::hex << this->line[0] << " '" << flush << (char) this->line[0] << "')."
              << " (note: using zlib version " << zlibVersion()
              << "; compiled with zlib version " << ZLIB_VERSION << ")\n" << flush;
         exit(EXIT_FAILURE);
+	
+    } else if (gzeof(this->gz_fh)) {
+        cerr << "Error: '" << path << "', unknown file format.\n" << flush;
+        exit(EXIT_FAILURE);
     }
-    gzrewind(gz_fh);
+
+    memset(this->line, '\0', max_len);
+    gzrewind(this->gz_fh);
 }
 
 Seq *
@@ -77,7 +93,7 @@ GzFasta::next_seq(Seq &s)
 
     //
     // Check the contents of the line buffer. When we finish reading a FASTA record
-    // the buffer will either contain whitespace or the header of the next FAST
+    // the buffer will either contain whitespace or the header of the next FASTA
     // record.
     //
     while (this->line[0] != '>' && !gzeof(this->gz_fh)) {
