@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2010-2015, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2010-2021, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -196,19 +196,20 @@ populate_kmer_hash(map<int, MergedStack *> &merged, KmerHashMap &kmer_map, vecto
     MergedStack    *tag;
     vector<char *>  kmers;
     bool            exists;
+    int             num_kmers;
 
     //
     // Break each stack down into k-mers and create a hash map of those k-mers
     // recording in which sequences they occur.
     //
-    int num_kmers = strlen(merged.begin()->second->con) - kmer_len + 1;
-
     for (it = merged.begin(); it != merged.end(); it++) {
         tag = it->second;
 
         // Don't compute distances for masked tags
         if (tag->masked) continue;
 
+        num_kmers = tag->len - kmer_len + 1;
+        
         generate_kmers(tag->con, kmer_len, num_kmers, kmers);
 
         // Hash the kmers
@@ -248,7 +249,7 @@ populate_kmer_hash(map<int, Locus *> &catalog, CatKmerHashMap &kmer_map, vector<
     for (it = catalog.begin(); it != catalog.end(); it++) {
         tag = it->second;
 
-        num_kmers = strlen(tag->con) - kmer_len + 1;
+        num_kmers = tag->len - kmer_len + 1;
 
         //
         // Iterate through the possible Catalog alleles
