@@ -223,6 +223,7 @@ public:
         this->_batch_total_loci    = 0;
         this->_batch_seen_loci     = 0;
         this->_filtered_sites      = 0;
+        this->_filtered_genotypes  = 0;
         this->_total_sites         = 0;
         this->_variant_sites       = 0;
     }
@@ -255,7 +256,7 @@ public:
     void   filter_snps(LocBin& loc, const MetaPopInfo& mpopi, ostream &log_fh);
     void   filter_haps(LocBin& loc, const MetaPopInfo& mpopi, ostream &log_fh);
     void   filter_fixed_sites(LocBin& loc, const MetaPopInfo& mpopi, ostream &log_fh);
-    void   gt_depth_filter(Datum **d, const CSLocus *cloc);
+    void   gt_depth_filter(Datum **d, const CSLocus *cloc, ostream &log_fh);
     void   keep_single_snp(CSLocus* cloc, Datum** d, size_t n_samples, const LocTally* t) const;
     void   keep_random_snp(CSLocus* cloc, Datum** d, size_t n_samples, const LocTally* t) const;
 
@@ -266,6 +267,7 @@ public:
     size_t batch_seen()     const { return this->_batch_seen_loci; }
     size_t batch_total()    const { return this->_batch_total_loci; }
     size_t filtered_sites() const { return this->_filtered_sites; }
+    size_t filtered_genotypes() const { return this->_filtered_genotypes; }
     size_t total_sites()    const { return this->_total_sites; }
     size_t variant_sites()  const { return this->_variant_sites; }
     void   locus_seen();
@@ -291,6 +293,7 @@ private:
     size_t  _batch_total_loci;
     size_t  _batch_seen_loci;
     size_t  _filtered_sites;
+    size_t  _filtered_genotypes;
     size_t  _total_sites;
     size_t  _variant_sites;
 
