@@ -97,8 +97,9 @@ uint max_bc_size_2 = 0;
 //
 // Kmer data for adapter filtering.
 //
-int kmer_size = 5;
-int distance  = 1;
+int kmer_size_1 = 11;
+int kmer_size_2 = 11;
+int adp_mm_dist = 1;
 int adp_1_len = 0;
 int adp_2_len = 0;
 AdapterHash adp_1_kmers, adp_2_kmers;
@@ -162,15 +163,15 @@ int main (int argc, char* argv[]) {
     if (filter_adapter) {
         cerr << "Filtering reads for adapter sequence:\n";
         if (adapter_1 != NULL) {
+            init_adapter_seq(kmer_size_1, adapter_1, adp_1_len, adp_mm_dist, adp_1_kmers);
             cerr << "  " << adapter_1 << "\n";
-            init_adapter_seq(kmer_size, adapter_1, adp_1_len, adp_1_kmers);
         }
         if (adapter_2 != NULL) {
+            init_adapter_seq(kmer_size_2, adapter_2, adp_2_len, adp_mm_dist, adp_2_kmers);
             cerr << "  " << adapter_2 << "\n";
-            init_adapter_seq(kmer_size, adapter_2, adp_2_len, adp_2_kmers);
         }
 
-        cerr << "    " << ::distance << " mismatches allowed to adapter sequence.\n";
+        cerr << "    " << adp_mm_dist << " mismatches allowed to adapter sequence.\n";
     }
 
     vector<pair<string, string> >        files;
@@ -526,7 +527,7 @@ process_paired_reads(string prefix_1,
         parse_input_record(s_2, r_2);
         counter["total"] += 2;
 
-        if (force_poly_g == false && r_1->check_poly_g()) check_poly_g = true;
+        if (force_poly_g == false && clean == true && r_1->check_poly_g()) check_poly_g = true;
         
         //
         // If a BestRAD protocol was used, check which read the barcode/restriction cutsite is on
@@ -1032,8 +1033,8 @@ process_paired_reads_parallel(string prefix_1,
 		parse_input_record(s_2, r_2);
 		cntr["total"] += 2;
 
-                if (force_poly_g == false && r_1->check_poly_g()) check_poly_g = true;
-                
+                if (force_poly_g == false && clean == true && r_1->check_poly_g()) check_poly_g = true;
+
 		//
 		// If a BestRAD protocol was used, check which read the barcode/restriction cutsite is on
 		// and transpose the reads if necessary.
@@ -1232,7 +1233,7 @@ process_reads(string prefix,
 
         parse_input_record(s, r);
 
-        if (force_poly_g == false && r->check_poly_g()) check_poly_g = true;
+        if (force_poly_g == false && clean == true && r->check_poly_g()) check_poly_g = true;
                 
         if (barcode_type == inline_null ||
             barcode_type == index_null)
@@ -1599,8 +1600,8 @@ process_reads_parallel(string prefix,
 		
 		parse_input_record(s, r);
 
-                if (force_poly_g == false && r->check_poly_g()) check_poly_g = true;
-                
+                if (force_poly_g == false && clean == true && r->check_poly_g()) check_poly_g = true;
+
 		bc = new BarcodePair();
 		//
 		// If no barcodes were specified, set the barcode object to be the input file name so
@@ -1757,7 +1758,8 @@ process_singlet(RawRead *href,
     //   Either the user has forced the check on, and check_poly_g is true, or we turned it on
     //   internally via href->check_poly_g because of the machine type that generated the data.
     //
-    if ((check_poly_g || href->check_poly_g()) &&
+    //if ((check_poly_g || href->check_poly_g()) &&
+    if (check_poly_g &&
         check_poly_g_run(href, href->inline_bc_len, len_limit) <= 0) {
         counter["poly_g"]++;
         if (barcode_type != null_null)
@@ -1773,10 +1775,10 @@ process_singlet(RawRead *href,
         int res = 1;
         if (paired_end == true  && adp_2_len > 0)
             res = filter_adapter_seq(href, adapter_2, adp_2_len, adp_2_kmers,
-                                     kmer_size, ::distance, len_limit);
+                                     kmer_size_2, adp_mm_dist, len_limit);
         if (paired_end == false && adp_1_len > 0)
             res = filter_adapter_seq(href, adapter_1, adp_1_len, adp_1_kmers,
-                                     kmer_size, ::distance, len_limit);
+                                     kmer_size_1, adp_mm_dist, len_limit);
         if (res <= 0) {
             // cerr << "Sequence " << href->seq << " contains adapter.\n";
             counter["adapter"]++;
@@ -2425,7 +2427,7 @@ int parse_command_line(int argc, char* argv[]) {
             filter_adapter = true;
             break;
         case 'T':
-            ::distance = is_integer(optarg);
+            adp_mm_dist = is_integer(optarg);
             break;
         case 'H':
             retain_header = true;
