@@ -81,10 +81,11 @@ uint max_bc_size_2 = 0;
 //
 // Kmer data for adapter filtering.
 //
-int kmer_size = 5;
-int distance  = 1;
-int adp_1_len = 0;
-int adp_2_len = 0;
+int kmer_size_1 = 11;
+int kmer_size_2 = 11;
+int adp_mm_dist = 1;
+int adp_1_len   = 0;
+int adp_2_len   = 0;
 AdapterHash adp_1_kmers, adp_2_kmers;
 
 int main (int argc, char* argv[]) {
@@ -112,13 +113,13 @@ int main (int argc, char* argv[]) {
         cerr << "Filtering reads for adapter sequence:\n";
         if (adapter_1 != NULL) {
             cerr << "  " << adapter_1 << "\n";
-            init_adapter_seq(kmer_size, adapter_1, adp_1_len, adp_1_kmers);
+            init_adapter_seq(kmer_size_1, adapter_1, adp_1_len, adp_mm_dist, adp_1_kmers);
         }
         if (adapter_2 != NULL) {
             cerr << "  " << adapter_2 << "\n";
-            init_adapter_seq(kmer_size, adapter_2, adp_2_len, adp_2_kmers);
+            init_adapter_seq(kmer_size_2, adapter_2, adp_2_len, adp_mm_dist, adp_2_kmers);
         }
-        cerr << "    " << distance << " mismatches allowed to adapter sequence.\n";
+        cerr << "    " << adp_mm_dist << " mismatches allowed to adapter sequence.\n";
     }
 
     vector<pair<string, string> >        files;
@@ -631,10 +632,10 @@ process_singlet(RawRead *href,
         int res = 1;
         if (paired_end == true  && adp_2_len > 0)
             res = filter_adapter_seq(href, adapter_2, adp_2_len, adp_2_kmers,
-                                     kmer_size, distance, len_limit);
+                                     kmer_size_2, adp_mm_dist, len_limit);
         if (paired_end == false && adp_1_len > 0)
             res = filter_adapter_seq(href, adapter_1, adp_1_len, adp_1_kmers,
-                                     kmer_size, distance, len_limit);
+                                     kmer_size_1, adp_mm_dist, len_limit);
         if (res == 0) {
             counter["adapter"]++;
             href->retain = 0;
@@ -1014,7 +1015,7 @@ int parse_command_line(int argc, char* argv[]) {
             filter_adapter = true;
             break;
         case 'T':
-            distance = is_integer(optarg);
+            adp_mm_dist = is_integer(optarg);
             break;
         case 'L':
             len_limit = is_integer(optarg);
