@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2010-2023, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2010-2024, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -1298,21 +1298,21 @@ int parse_command_line(int argc, char* argv[]) {
             {"help",              no_argument, NULL, 'h'},
             {"version",           no_argument, NULL, 'v'},
             {"aligned",           no_argument, NULL, 'g'},
-            {"verify-hap",        no_argument, NULL, 'x'}, {"verify_hap",        no_argument, NULL, 'x'},
-            {"uniq-haplotypes",   no_argument, NULL, 'u'}, {"uniq_haplotypes",   no_argument, NULL, 'u'},
-            {"disable-gapped",    no_argument, NULL, 'G'}, {"disable_gapped",    no_argument, NULL, 'G'},
-            {"threads",     required_argument, NULL, 'p'},
+            {"verify-hap",        no_argument, NULL, 'x'},
+            {"uniq-haplotypes",   no_argument, NULL, 'u'},
+            {"disable-gapped",    no_argument, NULL, 'G'},
+            {"threads",     required_argument, NULL, 't'},
             {"catalog",     required_argument, NULL, 'c'},
             {"sample",      required_argument, NULL, 's'},
-            {"out-path",    required_argument, NULL, 'o'}, {"out_path",    required_argument, NULL, 'o'},
-            {"in-path",     required_argument, NULL, 'P'}, {"in_path",     required_argument, NULL, 'P'},
+            {"out-path",    required_argument, NULL, 'o'},
+            {"in-path",     required_argument, NULL, 'P'},
             {"popmap",      required_argument, NULL, 'M'},
             {"write-all-matches", no_argument, NULL, 2001},
             {0, 0, 0, 0}
         };
 
         int option_index = 0;
-        int c = getopt_long(argc, argv, "hgGxuvs:c:o:p:P:M:", long_options, &option_index);
+        int c = getopt_long(argc, argv, "hgGxuvs:c:o:p:t:P:M:", long_options, &option_index);
 
         // Detect the end of the options.
         if (c == -1)
@@ -1323,6 +1323,7 @@ int parse_command_line(int argc, char* argv[]) {
             help();
             break;
         case 'p':
+        case 't':
             num_threads = atoi(optarg);
             break;
         case 's':
@@ -1435,13 +1436,13 @@ void version() {
 
 void help() {
     cerr << "sstacks " << VERSION << "\n"
-              << "sstacks -P dir -M popmap [-p n_threads]" << "\n"
-              << "sstacks -c catalog_path -s sample_path [-s sample_path ...] -o path [-p n_threads]" << "\n"
+              << "sstacks -P dir -M popmap [-t n_threads]" << "\n"
+              << "sstacks -c catalog_path -s sample_path [-s sample_path ...] -o path [-t n_threads]" << "\n"
               << "  -P,--in-path: path to the directory containing Stacks files.\n"
               << "  -M,--popmap: path to a population map file from which to take sample names.\n"
               << "  -s,--sample: filename prefix from which to load sample loci." << "\n"
               << "  -c,--catalog: path to the catalog." << "\n"
-              << "  -p,--threads: enable parallel execution with n_threads threads.\n"
+              << "  -t,--threads: enable parallel execution with n_threads threads.\n"
               << "  -o,--out-path: output path to write results." << "\n"
               << "  -x: don't verify haplotype of matching locus." << "\n"
               << "\n"
