@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2010-2023, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2010-2024, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -47,7 +47,7 @@ enum snp_type  {snp_type_het, snp_type_hom, snp_type_unk, snp_type_discarded};
 enum read_type {primary, secondary};
 enum searcht   {sequence, genomic_loc};
 enum corr_type {p_value, bonferroni_win, bonferroni_gen, no_correction};
-enum methylt   {unmethyl_cpg, unmethyl_chg, unmethyl_chh, unmethyl_unk, irrelevant};
+enum methylt   {unmethyl_cpg, unmethyl_chg, unmethyl_chh, unmethyl_unk, confounded, irrelevant};
 
 class SNP {
  public:
