@@ -1,3 +1,22 @@
+// -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
+//
+// Copyright 2016-2023, Julian Catchen <jcatchen@illinois.edu>
+//
+// This file is part of Stacks.
+//
+// Stacks is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Stacks is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Stacks.  If not, see <http://www.gnu.org/licenses/>.
+//
 #include <cmath>
 #include <cstring>
 #include <iostream>
@@ -21,7 +40,8 @@
 void parse_command_line(int argc, char* argv[]);
 void report_options(ostream& os);
 int  run();
-void run(const vector<int>& cloc_ids,
+void run(const map<string, size_t> &sample_ids,
+	 const vector<int>& cloc_ids,
          const string& header_sq_lines,
          const unordered_map<int,size_t>& cloc_lengths,
          size_t sample_i, ostream& os
@@ -31,13 +51,14 @@ void cigar_apply_to_locus(Locus* l, const Cigar& c);
 //
 // Argument globals.
 //
-bool quiet = false;
-string in_dir;
+string         in_dir;
 vector<string> samples;
-string popmap_path;
+string         popmap_path;
 vector<string> pe_reads_paths;
-FileT pe_reads_format;
-int num_threads = 1;
+FileT          pe_reads_format;
+
+bool quiet       = false;
+int  num_threads = 1;
 
 bool dbg_reversed_pe_reads = false;
 bool dbg_only_bijective_loci = false;
@@ -50,7 +71,9 @@ unique_ptr<LogAlterator> logger = NULL;
 
 // main()
 // ==========
-int main(int argc, char* argv[]) {
+int
+main(int argc, char* argv[])
+{
     IF_NDEBUG_TRY
 
     // Parse arguments
@@ -80,26 +103,46 @@ int main(int argc, char* argv[]) {
     IF_NDEBUG_CATCH_ALL_EXCEPTIONS
 }
 
-int run() {
-
+int
+run()
+{
     //
     // Read the catalog.
     //
     cout << "Loading the catalog..." << endl;
-    map<int, Locus*> catalog;
+    map<int, Locus*>    catalog;
+    map<string, size_t> sample_ids;
+
     string catalog_prefix = in_dir + "catalog";
-    bool dummy;
-    int rv = load_loci(catalog_prefix, catalog, 0, false, dummy, false);
-    if (rv != 1) {
+    bool   compressed;
+    size_t max_sample_id  = 0;
+    size_t next_sample_id = 1;
+    
+    if (!load_loci(catalog_prefix, catalog, 0, false, compressed, false)) {
         cerr << "Error: Unable to load catalog '" << catalog_prefix << "'.\n";
         throw exception();
     }
-
+    //
+    // Assign arbitrary sample IDs to the incomming samples, respecting the IDs already assigend by cstacks.
+    // Since not all samples have to be part of the catalog, we may have additional samples now being
+    // processed that are not in the catalog and do not have an existing ID.
+    //
+    if (!load_catalog_samples(catalog_prefix, sample_ids, max_sample_id)) {
+	cerr << "Error: Unable to load catalog sample list '" << catalog_prefix << "'.\n";
+	throw exception();
+    }
+    next_sample_id = max_sample_id + 1;
+    for (size_t i = 0; i < samples.size(); ++i)
+	if (sample_ids.count(samples[i]) == 0) {
+	    sample_ids[samples[i]] = next_sample_id;
+	    next_sample_id++;
+	}
+    
     //
     // Create the BAM target list.
     //
     stringstream header_sq_lines_ss;
-    vector<int> cloc_ids;
+    vector<int>  cloc_ids;
     unordered_map<int,size_t> cloc_lengths;
     cloc_ids.reserve(catalog.size());
     for (auto& cloc : catalog) {
@@ -125,7 +168,7 @@ int run() {
     #pragma omp parallel
     {
         #pragma omp for schedule(dynamic)
-        for (size_t i=0; i<samples.size(); ++i) {
+        for (size_t i = 0; i < samples.size(); ++i) {
             if (omp_return != 0)
                 continue;
             try {
@@ -133,7 +176,7 @@ int run() {
                 cout << "Processing sample '" << samples[i] << "'...\n" << flush;
 
                 stringstream ss;
-                run(cloc_ids, header_sq_lines, cloc_lengths, i, ss);
+                run(sample_ids, cloc_ids, header_sq_lines, cloc_lengths, i, ss);
                 outputs[i] = ss.str();
 
             } catch (exception& e) {
@@ -155,12 +198,14 @@ int run() {
     return 0;
 }
 
-void run(const vector<int>& cloc_ids,
+void
+run(const map<string, size_t> &sample_ids,
+    const vector<int>& cloc_ids,
     const string& header_sq_lines,
     const unordered_map<int,size_t>& cloc_lengths,
     size_t sample_i,
-    ostream& os
-) {
+    ostream& os)
+{
     ostream& cout = os;
     cout << "Sample '" << samples.at(sample_i) << "':";
 
@@ -171,7 +216,7 @@ void run(const vector<int>& cloc_ids,
     //
     map<int, Locus*> sloci;
     vector<CatMatch*> matches;
-    int sample_id = -1;
+    int sample_id = sample_ids.at(samples.at(sample_i));
     {
         load_catalog_matches(prefix_path, matches, false);
         if (matches.empty()) {
@@ -179,7 +224,7 @@ void run(const vector<int>& cloc_ids,
                  << prefix_path + ".matches.tsv(.gz)'.\n";
             throw exception();
         }
-        sample_id = matches[0]->sample_id;
+        matches[0]->sample_id = sample_id;
 
         bool dummy;
         int rv = load_loci(prefix_path, sloci, 2, false, dummy, false);
