@@ -2293,7 +2293,7 @@ calc_coverage_distribution(map<int, MergedStack *> &merged,
     tot_depth = 0.0;
 
     size_t not_blacklisted = 0;
-    for (const pair<int, MergedStack*>& mtag : merged) {
+    for (const pair<const int, MergedStack*>& mtag : merged) {
         if (mtag.second->blacklisted)
             continue;
         ++not_blacklisted;
@@ -2305,7 +2305,7 @@ calc_coverage_distribution(map<int, MergedStack *> &merged,
     }
     mean = tot_depth / not_blacklisted;
 
-    for (const pair<int, MergedStack*>& mtag : merged)
+    for (const pair<const int, MergedStack*>& mtag : merged)
         if (!mtag.second->blacklisted)
             stdev += pow(mtag.second->count - mean, 2);
     stdev /= not_blacklisted;
@@ -2785,30 +2785,30 @@ int parse_command_line(int argc, char* argv[]) {
         static struct option long_options[] = {
             {"help",             no_argument,       NULL, 'h'},
             {"version",          no_argument,       NULL, 'v'},
-            {"infile-type",      required_argument, NULL, 't'}, {"infile_type",      required_argument, NULL, 't'},
+            {"in-type",          required_argument, NULL, 't'},  {"infile-type",      required_argument, NULL, 't'},
             {"file",             required_argument, NULL, 'f'},
-            {"outpath",          required_argument, NULL, 'o'},
-            {"name",             required_argument, NULL, 1002},
+            {"out-path",         required_argument, NULL, 'o'},
+            {"name",             required_argument, NULL, 'n'},
             {"id",               required_argument, NULL, 'i'},
-            {"min-cov",          required_argument, NULL, 'm'}, {"min_cov",          required_argument, NULL, 'm'},
-            {"max-dist",         required_argument, NULL, 'M'}, {"max_dist",         required_argument, NULL, 'M'},
-            {"max-sec-dist",     required_argument, NULL, 'N'}, {"max_sec_dist",     required_argument, NULL, 'N'},
-            {"max-locus-stacks", required_argument, NULL, 'K'}, {"max_locus_stacks", required_argument, NULL, 'K'},
-            {"k-len",            required_argument, NULL, 'k'}, {"k_len",            required_argument, NULL, 'k'},
-            {"num-threads",      required_argument, NULL, 'p'}, {"num_threads",      required_argument, NULL, 'p'},
+            {"min-cov",          required_argument, NULL, 'm'},  {"min_cov",          required_argument, NULL, 'm'},
+            {"max-dist",         required_argument, NULL, 'M'},  {"max_dist",         required_argument, NULL, 'M'},
+            {"max-sec-dist",     required_argument, NULL, 'N'},  {"max_sec_dist",     required_argument, NULL, 'N'},
+            {"max-locus-stacks", required_argument, NULL, 'K'},  {"max_locus_stacks", required_argument, NULL, 'K'},
+            {"k-len",            required_argument, NULL, 'k'},  {"k_len",            required_argument, NULL, 'k'},
+            {"threads",          required_argument, NULL, 'p'},
             {"deleverage",       no_argument,       NULL, 'd'},
             {"keep-high-cov",    no_argument,       NULL, 1000}, {"keep_high_cov",    no_argument,       NULL, 1000},
             {"high-cov-thres",   required_argument, NULL, 1001}, {"high_cov_thres",   required_argument, NULL, 1001},
-            {"retain-rem",       no_argument,       NULL, 'R'}, {"retain_rem",       no_argument,       NULL, 'R'},
+            {"retain-rem",       no_argument,       NULL, 'R'},  {"retain_rem",       no_argument,       NULL, 'R'},
             {"graph",            no_argument,       NULL, 'g'},
-            {"sec-hapl",         no_argument,       NULL, 'H'}, {"sec_hapl",         no_argument,       NULL, 'H'},
+            {"sec-hapl",         no_argument,       NULL, 'H'},  
             {"disable-gapped",   no_argument,       NULL, 'G'},
-            {"max-gaps",         required_argument, NULL, 'X'}, {"max_gaps",         required_argument, NULL, 'X'},
-            {"min-aln-len",      required_argument, NULL, 'x'}, {"min_aln_len",      required_argument, NULL, 'x'},
-            {"model-type",       required_argument, NULL, 'T'}, {"model_type",       required_argument, NULL, 'T'},
-            {"bc-err-freq",      required_argument, NULL, 'e'}, {"bc_err_freq",      required_argument, NULL, 'e'},
-            {"bound-low",        required_argument, NULL, 'L'}, {"bound_low",        required_argument, NULL, 'L'},
-            {"bound-high",       required_argument, NULL, 'U'}, {"bound_high",       required_argument, NULL, 'U'},
+            {"max-gaps",         required_argument, NULL, 'X'},  
+            {"min-aln-len",      required_argument, NULL, 'x'},  
+            {"model-type",       required_argument, NULL, 'T'},  
+            {"bc-err-freq",      required_argument, NULL, 'e'},  
+            {"bound-low",        required_argument, NULL, 'L'},  
+            {"bound-high",       required_argument, NULL, 'U'},  
             {"alpha",            required_argument, NULL, 'A'},
             {"r-deprecated",     no_argument,       NULL, 'r'},
             {"force-diff-len",   no_argument,       NULL, 1003}, {"force_diff_len",   no_argument,       NULL, 1003},
@@ -2818,7 +2818,7 @@ int parse_command_line(int argc, char* argv[]) {
         // getopt_long stores the option index here.
         int option_index = 0;
 
-        c = getopt_long(argc, argv, "GhHvdrgRA:L:U:f:o:s:i:m:e:p:t:M:N:K:k:T:X:x:", long_options, &option_index);
+        c = getopt_long(argc, argv, "GhHvdrgRA:L:U:f:o:s:i:m:n:e:p:t:M:N:K:k:T:X:x:", long_options, &option_index);
 
         // Detect the end of the options.
         if (c == -1)
@@ -2828,7 +2828,7 @@ int parse_command_line(int argc, char* argv[]) {
         case 'h':
             help();
             break;
-        case 't':
+        case 'i':
             if (strcmp(optarg, "tsv") == 0)
                 in_file_type = FileT::tsv;
             else if (strcmp(optarg, "fasta") == 0)
@@ -2848,11 +2848,9 @@ int parse_command_line(int argc, char* argv[]) {
         case 'o':
             out_path = optarg;
             break;
-        case 1002:
+        case 'n':
             sample_name = optarg;
             break;
-        case 'i':
-            break;
         case 'm':
             min_merge_cov = is_integer(optarg);
             break;
@@ -2925,6 +2923,7 @@ int parse_command_line(int argc, char* argv[]) {
             call_sec_hapl = false;
             break;
         case 'p':
+        case 't':
             num_threads = is_integer(optarg);
             break;
         case 'v':
@@ -2933,9 +2932,6 @@ int parse_command_line(int argc, char* argv[]) {
         case 1003:
             force_diff_len = true;
             break;
-        case 'r': // deprecated Dec 2016, v1.45
-            cerr << "Warning: Ignoring deprecated option -r (this has become the default).\n";
-            break;
         case '?':
             // getopt_long already printed an error message.
             help();
@@ -3024,29 +3020,29 @@ void version() {
 
 void help() {
     cerr << "ustacks " << VERSION << "\n"
-         << "ustacks -f file_path -o path [-M max_dist] [-m min_cov] [-p num_threads]" << "\n"
-         << "  f: input file path.\n"
-         << "  o: output path to write results.\n"
-         << "  M: Maximum distance (in nucleotides) allowed between stacks (default 2).\n"
-         << "  m: Minimum depth of coverage required to create a stack (default 3).\n"
-         << "  N: Maximum distance allowed to align secondary reads to primary stacks (default: M + 2).\n"
-         << "  p: enable parallel execution with num_threads threads.\n"
-         << "  t: input file type. Supported types: fasta, fastq, gzfasta, or gzfastq (default: guess).\n"
-         << "  --name: a name for the sample (default: input file name minus the suffix).\n"
-         << "  R: retain unused reads.\n"
-         << "  H: disable calling haplotypes from secondary reads.\n"
+         << "ustacks -f in_path -o out_path [-M max_dist] [-m min_reads] [-t num_threads]" << "\n"
+         << "  -f,--file: input file path.\n"
+         << "  -o,--out-path: output path to write results.\n"
+         << "  -M: Maximum distance (in nucleotides) allowed between stacks (default 2).\n"
+         << "  -m: Minimum number of reads to seed a new stack (default 3).\n"
+         << "  -N: Maximum distance allowed to align secondary reads to primary stacks (default: M + 2).\n"
+         << "  -t,--threads: enable parallel execution with num_threads threads.\n"
+         << "  -i,--in-type: input file type. Supported types: fasta, fastq, gzfasta, or gzfastq (default: guess).\n"
+         << "  -n,--name: a name for the sample (default: input file name minus the suffix).\n"
+         << "  -R: retain unused reads.\n"
+         << "  -H: disable calling haplotypes from secondary reads.\n"
          << "\n"
          << "  Stack assembly options:\n"
          << "    --force-diff-len: allow raw input reads of different lengths, e.g. after trimming (default: ustacks perfers raw input reads of uniform length).\n"
          << "    --keep-high-cov: disable the algorithm that removes highly-repetitive stacks and nearby errors.\n"
          << "    --high-cov-thres: highly-repetitive stacks threshold, in standard deviation units (default: 3.0).\n"
          << "    --max-locus-stacks <num>: maximum number of stacks at a single de novo locus (default 3).\n"
-         << "     --k-len <len>: specify k-mer size for matching between alleles and loci (automatically calculated by default).\n"
+         << "    --k-len <len>: specify k-mer size for matching between alleles and loci (automatically calculated by default).\n"
          << "    --deleverage: enable the Deleveraging algorithm, used for resolving over merged tags.\n\n"
          << "  Gapped assembly options:\n"
          << "    --max-gaps: number of gaps allowed between stacks before merging (default: 2).\n"
-         << "    --min-aln-len: minimum length of aligned sequence in a gapped alignment (default: 0.80).\n\n"
-         << "    --disable-gapped: do not preform gapped alignments between stacks (default: gapped alignements enabled).\n"
+         << "    --min-aln-len: minimum length of aligned sequence in a gapped alignment (default: 0.80).\n"
+         << "    --disable-gapped: do not preform gapped alignments between stacks (default: gapped alignements enabled).\n\n"
          << "  Model options:\n"
          << "    --model-type: either 'snp' (default), 'bounded', or 'fixed'\n"
          << "    For the SNP or Bounded SNP model:\n"
