@@ -34,6 +34,7 @@
 #include <dirent.h>
 #include <zlib.h>
 
+#include "htslib/bgzf.h"
 #include "constants.h"
 #include "nucleotides.h"
 
@@ -206,6 +207,9 @@ void check_open (std::ofstream& fs, const string& path) {
 inline
 void check_open (const gzFile fs, const string& path)
     {if (fs == NULL) {cerr << "Error: Failed to gz-open file '" << path << "'.\n"; throw exception();}}
+inline
+void check_open (const BGZF* fs, const string& path)
+    {if (fs == NULL) {cerr << "Error: Failed to bgzf-open file '" << path << "'.\n"; throw exception();}}
 
 //
 // Check that a directory exists or try to create it.
